package java.awt.image;

import java.util.Arrays;
import java.awt.color.ICC_ColorSpace;
import java.awt.color.ColorSpace;

public class ComponentColorModel extends ColorModel
{
    private boolean signed;
    private boolean is_sRGB_stdScale;
    private boolean is_LinearRGB_stdScale;
    private boolean is_LinearGray_stdScale;
    private boolean is_ICCGray_stdScale;
    private byte[] tosRGB8LUT;
    private byte[] fromsRGB8LUT8;
    private short[] fromsRGB8LUT16;
    private byte[] fromLinearGray16ToOtherGray8LUT;
    private short[] fromLinearGray16ToOtherGray16LUT;
    private boolean needScaleInit;
    private boolean noUnnorm;
    private boolean nonStdScale;
    private float[] min;
    private float[] diffMinMax;
    private float[] compOffset;
    private float[] compScale;
    
    public ComponentColorModel(ColorSpace colorSpace, int[] array, boolean b, boolean b2, int n, int i) {
        super(bitsHelper(i, colorSpace, b), bitsArrayHelper(array, i, colorSpace, b), colorSpace, b, b2, n, i);
        switch (i) {
            case 0:
            case 1:
            case 3: {
                this.signed = false;
                this.needScaleInit = true;
                break;
            }
            case 2: {
                this.signed = true;
                this.needScaleInit = true;
                break;
            }
            case 4:
            case 5: {
                this.signed = true;
                this.needScaleInit = false;
                this.noUnnorm = true;
                this.nonStdScale = false;
                break;
            }
            default: {
                throw new IllegalArgumentException("This constructor is not compatible with transferType " + i);
            }
        }
        this.setupLUTs();
    }
    
    public ComponentColorModel(ColorSpace colorSpace, boolean b, boolean b2, int n, int n2) {
        this(colorSpace, null, b, b2, n, n2);
    }
    
    private static int bitsHelper(int n, ColorSpace colorSpace, boolean b) {
        int dataTypeSize = DataBuffer.getDataTypeSize(n);
        int numComponents = colorSpace.getNumComponents();
        if (b) {
            ++numComponents;
        }
        return dataTypeSize * numComponents;
    }
    
    private static int[] bitsArrayHelper(int[] array, int n, ColorSpace colorSpace, boolean b) {
        switch (n) {
            case 0:
            case 1:
            case 3: {
                if (array != null) {
                    return array;
                }
                break;
            }
        }
        int dataTypeSize = DataBuffer.getDataTypeSize(n);
        int numComponents = colorSpace.getNumComponents();
        if (b) {
            ++numComponents;
        }
        int[] array2 = new int[numComponents];
        for (int i = 0; i < numComponents; ++i) {
            array2[i] = dataTypeSize;
        }
        return array2;
    }
    
    private void setupLUTs() {
        if (this.is_sRGB) {
            this.is_sRGB_stdScale = true;
            this.nonStdScale = false;
        }
        else if (ColorModel.isLinearRGBspace(this.colorSpace)) {
            this.is_LinearRGB_stdScale = true;
            this.nonStdScale = false;
            if (this.transferType == 0) {
                this.tosRGB8LUT = ColorModel.getLinearRGB8TosRGB8LUT();
                this.fromsRGB8LUT8 = ColorModel.getsRGB8ToLinearRGB8LUT();
            }
            else {
                this.tosRGB8LUT = ColorModel.getLinearRGB16TosRGB8LUT();
                this.fromsRGB8LUT16 = ColorModel.getsRGB8ToLinearRGB16LUT();
            }
        }
        else if (this.colorSpaceType == 6 && this.colorSpace instanceof ICC_ColorSpace && this.colorSpace.getMinValue(0) == 0.0f && this.colorSpace.getMaxValue(0) == 1.0f) {
            ICC_ColorSpace icc_ColorSpace = (ICC_ColorSpace)this.colorSpace;
            this.is_ICCGray_stdScale = true;
            this.nonStdScale = false;
            this.fromsRGB8LUT16 = ColorModel.getsRGB8ToLinearRGB16LUT();
            if (ColorModel.isLinearGRAYspace(icc_ColorSpace)) {
                this.is_LinearGray_stdScale = true;
                if (this.transferType == 0) {
                    this.tosRGB8LUT = ColorModel.getGray8TosRGB8LUT(icc_ColorSpace);
                }
                else {
                    this.tosRGB8LUT = ColorModel.getGray16TosRGB8LUT(icc_ColorSpace);
                }
            }
            else if (this.transferType == 0) {
                this.tosRGB8LUT = ColorModel.getGray8TosRGB8LUT(icc_ColorSpace);
                this.fromLinearGray16ToOtherGray8LUT = ColorModel.getLinearGray16ToOtherGray8LUT(icc_ColorSpace);
            }
            else {
                this.tosRGB8LUT = ColorModel.getGray16TosRGB8LUT(icc_ColorSpace);
                this.fromLinearGray16ToOtherGray16LUT = ColorModel.getLinearGray16ToOtherGray16LUT(icc_ColorSpace);
            }
        }
        else if (this.needScaleInit) {
            this.nonStdScale = false;
            int i = 0;
            while (i < this.numColorComponents) {
                if (this.colorSpace.getMinValue(i) != 0.0f || this.colorSpace.getMaxValue(i) != 1.0f) {
                    this.nonStdScale = true;
                    break;
                }
                ++i;
            }
            if (this.nonStdScale) {
                this.min = new float[this.numColorComponents];
                this.diffMinMax = new float[this.numColorComponents];
                for (int j = 0; j < this.numColorComponents; ++j) {
                    this.min[j] = this.colorSpace.getMinValue(j);
                    this.diffMinMax[j] = this.colorSpace.getMaxValue(j) - this.min[j];
                }
            }
        }
    }
    
    private void initScale() {
        this.needScaleInit = false;
        if (this.nonStdScale || this.signed) {
            this.noUnnorm = true;
        }
        else {
            this.noUnnorm = false;
        }
        float[] array2;
        float[] array3;
        switch (this.transferType) {
            case 0: {
                byte[] array = new byte[this.numComponents];
                for (int i = 0; i < this.numColorComponents; ++i) {
                    array[i] = 0;
                }
                if (this.supportsAlpha) {
                    array[this.numColorComponents] = (byte)((1 << this.nBits[this.numColorComponents]) - 1);
                }
                array2 = this.getNormalizedComponents(array, null, 0);
                for (int j = 0; j < this.numColorComponents; ++j) {
                    array[j] = (byte)((1 << this.nBits[j]) - 1);
                }
                array3 = this.getNormalizedComponents(array, null, 0);
                break;
            }
            case 1: {
                short[] array4 = new short[this.numComponents];
                for (int k = 0; k < this.numColorComponents; ++k) {
                    array4[k] = 0;
                }
                if (this.supportsAlpha) {
                    array4[this.numColorComponents] = (short)((1 << this.nBits[this.numColorComponents]) - 1);
                }
                array2 = this.getNormalizedComponents(array4, null, 0);
                for (int l = 0; l < this.numColorComponents; ++l) {
                    array4[l] = (short)((1 << this.nBits[l]) - 1);
                }
                array3 = this.getNormalizedComponents(array4, null, 0);
                break;
            }
            case 3: {
                int[] array5 = new int[this.numComponents];
                for (int n = 0; n < this.numColorComponents; ++n) {
                    array5[n] = 0;
                }
                if (this.supportsAlpha) {
                    array5[this.numColorComponents] = (1 << this.nBits[this.numColorComponents]) - 1;
                }
                array2 = this.getNormalizedComponents(array5, null, 0);
                for (int n2 = 0; n2 < this.numColorComponents; ++n2) {
                    array5[n2] = (1 << this.nBits[n2]) - 1;
                }
                array3 = this.getNormalizedComponents(array5, null, 0);
                break;
            }
            case 2: {
                short[] array6 = new short[this.numComponents];
                for (int n3 = 0; n3 < this.numColorComponents; ++n3) {
                    array6[n3] = 0;
                }
                if (this.supportsAlpha) {
                    array6[this.numColorComponents] = 32767;
                }
                array2 = this.getNormalizedComponents(array6, null, 0);
                for (int n4 = 0; n4 < this.numColorComponents; ++n4) {
                    array6[n4] = 32767;
                }
                array3 = this.getNormalizedComponents(array6, null, 0);
                break;
            }
            default: {
                array3 = (array2 = null);
                break;
            }
        }
        this.nonStdScale = false;
        int n5 = 0;
        while (n5 < this.numColorComponents) {
            if (array2[n5] != 0.0f || array3[n5] != 1.0f) {
                this.nonStdScale = true;
                break;
            }
            ++n5;
        }
        if (this.nonStdScale) {
            this.noUnnorm = true;
            this.is_sRGB_stdScale = false;
            this.is_LinearRGB_stdScale = false;
            this.is_LinearGray_stdScale = false;
            this.is_ICCGray_stdScale = false;
            this.compOffset = new float[this.numColorComponents];
            this.compScale = new float[this.numColorComponents];
            for (int n6 = 0; n6 < this.numColorComponents; ++n6) {
                this.compOffset[n6] = array2[n6];
                this.compScale[n6] = 1.0f / (array3[n6] - array2[n6]);
            }
        }
    }
    
    private int getRGBComponent(int n, int n2) {
        if (this.numComponents > 1) {
            throw new IllegalArgumentException("More than one component per pixel");
        }
        if (this.signed) {
            throw new IllegalArgumentException("Component value is signed");
        }
        if (this.needScaleInit) {
            this.initScale();
        }
        int[] array = null;
        switch (this.transferType) {
            case 0: {
                array = new byte[] { (byte)n };
                break;
            }
            case 1: {
                array = new short[] { (short)n };
                break;
            }
            case 3: {
                array = new int[] { n };
                break;
            }
        }
        return (int)(this.colorSpace.toRGB(this.getNormalizedComponents(array, null, 0))[n2] * 255.0f + 0.5f);
    }
    
    @Override
    public int getRed(int n) {
        return this.getRGBComponent(n, 0);
    }
    
    @Override
    public int getGreen(int n) {
        return this.getRGBComponent(n, 1);
    }
    
    @Override
    public int getBlue(int n) {
        return this.getRGBComponent(n, 2);
    }
    
    @Override
    public int getAlpha(int n) {
        if (!this.supportsAlpha) {
            return 255;
        }
        if (this.numComponents > 1) {
            throw new IllegalArgumentException("More than one component per pixel");
        }
        if (this.signed) {
            throw new IllegalArgumentException("Component value is signed");
        }
        return (int)((float)n / (float)((1 << this.nBits[0]) - 1) * 255.0f + 0.5f);
    }
    
    @Override
    public int getRGB(int n) {
        if (this.numComponents > 1) {
            throw new IllegalArgumentException("More than one component per pixel");
        }
        if (this.signed) {
            throw new IllegalArgumentException("Component value is signed");
        }
        return this.getAlpha(n) << 24 | this.getRed(n) << 16 | this.getGreen(n) << 8 | this.getBlue(n) << 0;
    }
    
    private int extractComponent(Object o, int n, int n2) {
        int n3 = this.supportsAlpha && this.isAlphaPremultiplied;
        int n4 = 0;
        int n5 = (1 << this.nBits[n]) - 1;
        int n12;
        switch (this.transferType) {
            case 2: {
                short[] array = (short[])(short[])o;
                float n6 = (float)((1 << n2) - 1);
                if (!(n3 == 0)) {
                    int n7 = array[this.numColorComponents];
                    if (n7 != 0) {
                        return (int)((float)array[n] / (float)n7 * n6 + 0.5f);
                    }
                    return 0;
                }
                else {
                    return (int)((float)array[n] / 32767.0f * n6 + 0.5f);
                }
            }
            case 4: {
                float[] array2 = (float[])(float[])o;
                float n8 = (float)((1 << n2) - 1);
                if (!(n3 == 0)) {
                    float n9 = array2[this.numColorComponents];
                    if (n9 != 0.0f) {
                        return (int)(array2[n] / n9 * n8 + 0.5f);
                    }
                    return 0;
                }
                else {
                    return (int)(array2[n] * n8 + 0.5f);
                }
            }
            case 5: {
                double[] array3 = (double[])(double[])o;
                double n10 = (double)((1 << n2) - 1);
                if (!(n3 == 0)) {
                    double n11 = array3[this.numColorComponents];
                    if (n11 != 0.0) {
                        return (int)(array3[n] / n11 * n10 + 0.5);
                    }
                    return 0;
                }
                else {
                    return (int)(array3[n] * n10 + 0.5);
                }
            }
            case 0: {
                byte[] array4 = (byte[])(byte[])o;
                n12 = (array4[n] & n5);
                n2 = 8;
                if (!(n3 == 0)) {
                    n4 = (array4[this.numColorComponents] & n5);
                    break;
                }
                break;
            }
            case 1: {
                short[] array5 = (short[])(short[])o;
                n12 = (array5[n] & n5);
                if (!(n3 == 0)) {
                    n4 = (array5[this.numColorComponents] & n5);
                    break;
                }
                break;
            }
            case 3: {
                int[] array6 = (int[])(int[])o;
                n12 = array6[n];
                if (!(n3 == 0)) {
                    n4 = array6[this.numColorComponents];
                    break;
                }
                break;
            }
            default: {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
        if (!(n3 == 0)) {
            if (n4 != 0) {
                return (int)((float)n12 / (float)n5 * ((float)((1 << this.nBits[this.numColorComponents]) - 1) / (float)n4) * (float)((1 << n2) - 1) + 0.5f);
            }
            return 0;
        }
        else {
            if (this.nBits[n] != n2) {
                return (int)((float)n12 / (float)n5 * (float)((1 << n2) - 1) + 0.5f);
            }
            return n12;
        }
    }
    
    private int getRGBComponent(Object o, int n) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.is_sRGB_stdScale) {
            return this.extractComponent(o, n, 8);
        }
        if (this.is_LinearRGB_stdScale) {
            return this.tosRGB8LUT[this.extractComponent(o, n, 16)] & 0xFF;
        }
        if (this.is_ICCGray_stdScale) {
            return this.tosRGB8LUT[this.extractComponent(o, 0, 16)] & 0xFF;
        }
        return (int)(this.colorSpace.toRGB(this.getNormalizedComponents(o, null, 0))[n] * 255.0f + 0.5f);
    }
    
    @Override
    public int getRed(Object o) {
        return this.getRGBComponent(o, 0);
    }
    
    @Override
    public int getGreen(Object o) {
        return this.getRGBComponent(o, 1);
    }
    
    @Override
    public int getBlue(Object o) {
        return this.getRGBComponent(o, 2);
    }
    
    @Override
    public int getAlpha(Object o) {
        if (!this.supportsAlpha) {
            return 255;
        }
        int numColorComponents = this.numColorComponents;
        int n = (1 << this.nBits[numColorComponents]) - 1;
        int n2;
        switch (this.transferType) {
            case 2: {
                return (int)((float)((short[])(short[])o)[numColorComponents] / 32767.0f * 255.0f + 0.5f);
            }
            case 4: {
                return (int)(((float[])(float[])o)[numColorComponents] * 255.0f + 0.5f);
            }
            case 5: {
                return (int)(((double[])(double[])o)[numColorComponents] * 255.0 + 0.5);
            }
            case 0: {
                n2 = (((byte[])(byte[])o)[numColorComponents] & n);
                break;
            }
            case 1: {
                n2 = (((short[])(short[])o)[numColorComponents] & n);
                break;
            }
            case 3: {
                n2 = ((int[])(int[])o)[numColorComponents];
                break;
            }
            default: {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
        if (this.nBits[numColorComponents] == 8) {
            return n2;
        }
        return (int)((float)n2 / (float)((1 << this.nBits[numColorComponents]) - 1) * 255.0f + 0.5f);
    }
    
    @Override
    public int getRGB(Object o) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.is_sRGB_stdScale || this.is_LinearRGB_stdScale) {
            return this.getAlpha(o) << 24 | this.getRed(o) << 16 | this.getGreen(o) << 8 | this.getBlue(o);
        }
        if (this.colorSpaceType == 6) {
            int red = this.getRed(o);
            return this.getAlpha(o) << 24 | red << 16 | red << 8 | red;
        }
        float[] rgb = this.colorSpace.toRGB(this.getNormalizedComponents(o, null, 0));
        return this.getAlpha(o) << 24 | (int)(rgb[0] * 255.0f + 0.5f) << 16 | (int)(rgb[1] * 255.0f + 0.5f) << 8 | (int)(rgb[2] * 255.0f + 0.5f) << 0;
    }
    
    @Override
    public Object getDataElements(int n, Object o) {
        int n2 = n >> 16 & 0xFF;
        int n3 = n >> 8 & 0xFF;
        int n4 = n & 0xFF;
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.signed) {
            switch (this.transferType) {
                case 2: {
                    short[] array;
                    if (o == null) {
                        array = new short[this.numComponents];
                    }
                    else {
                        array = (short[])(short[])o;
                    }
                    if (this.is_sRGB_stdScale || this.is_LinearRGB_stdScale) {
                        float n14 = 128.49803f;
                        if (this.is_LinearRGB_stdScale) {
                            n2 = (this.fromsRGB8LUT16[n2] & 0xFFFF);
                            n3 = (this.fromsRGB8LUT16[n3] & 0xFFFF);
                            n4 = (this.fromsRGB8LUT16[n4] & 0xFFFF);
                            n14 = 0.49999237f;
                        }
                        if (this.supportsAlpha) {
                            int n15 = n >> 24 & 0xFF;
                            array[3] = (short)(int)((float)n15 * 128.49803f + 0.5f);
                            if (this.isAlphaPremultiplied) {
                                n14 = (float)n15 * n14 * 0.003921569f;
                            }
                        }
                        array[0] = (short)(int)((float)n2 * n14 + 0.5f);
                        array[1] = (short)(int)((float)n3 * n14 + 0.5f);
                        array[2] = (short)(int)((float)n4 * n14 + 0.5f);
                    }
                    else if (this.is_LinearGray_stdScale) {
                        float n11 = (0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF)) / 65535.0f;
                        float n12 = 32767.0f;
                        if (this.supportsAlpha) {
                            int n13 = n >> 24 & 0xFF;
                            array[1] = (short)(int)((float)n13 * 128.49803f + 0.5f);
                            if (this.isAlphaPremultiplied) {
                                n12 = (float)n13 * n12 * 0.003921569f;
                            }
                        }
                        array[0] = (short)(int)(n11 * n12 + 0.5f);
                    }
                    else if (this.is_ICCGray_stdScale) {
                        int n8 = this.fromLinearGray16ToOtherGray16LUT[(int)(0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF) + 0.5f)] & 0xFFFF;
                        float n9 = 0.49999237f;
                        if (this.supportsAlpha) {
                            int n10 = n >> 24 & 0xFF;
                            array[1] = (short)(int)((float)n10 * 128.49803f + 0.5f);
                            if (this.isAlphaPremultiplied) {
                                n9 = (float)n10 * n9 * 0.003921569f;
                            }
                        }
                        array[0] = (short)(int)((float)n8 * n9 + 0.5f);
                    }
                    else {
                        float n5 = 0.003921569f;
                        float[] fromRGB = this.colorSpace.fromRGB(new float[] { (float)n2 * n5, (float)n3 * n5, (float)n4 * n5 });
                        if (this.nonStdScale) {
                            for (int i = 0; i < this.numColorComponents; ++i) {
                                fromRGB[i] = (fromRGB[i] - this.compOffset[i]) * this.compScale[i];
                                if (fromRGB[i] < 0.0f) {
                                    fromRGB[i] = 0.0f;
                                }
                                if (fromRGB[i] > 1.0f) {
                                    fromRGB[i] = 1.0f;
                                }
                            }
                        }
                        float n6 = 32767.0f;
                        if (this.supportsAlpha) {
                            int n7 = n >> 24 & 0xFF;
                            array[this.numColorComponents] = (short)(int)((float)n7 * 128.49803f + 0.5f);
                            if (this.isAlphaPremultiplied) {
                                n6 *= (float)n7 * 0.003921569f;
                            }
                        }
                        for (int j = 0; j < this.numColorComponents; ++j) {
                            array[j] = (short)(int)(fromRGB[j] * n6 + 0.5f);
                        }
                    }
                    return array;
                }
                case 4: {
                    float[] array2;
                    if (o == null) {
                        array2 = new float[this.numComponents];
                    }
                    else {
                        array2 = (float[])(float[])o;
                    }
                    if (this.is_sRGB_stdScale || this.is_LinearRGB_stdScale) {
                        float n22;
                        if (this.is_LinearRGB_stdScale) {
                            n2 = (this.fromsRGB8LUT16[n2] & 0xFFFF);
                            n3 = (this.fromsRGB8LUT16[n3] & 0xFFFF);
                            n4 = (this.fromsRGB8LUT16[n4] & 0xFFFF);
                            n22 = 1.5259022E-5f;
                        }
                        else {
                            n22 = 0.003921569f;
                        }
                        if (this.supportsAlpha) {
                            array2[3] = (float)(n >> 24 & 0xFF) * 0.003921569f;
                            if (this.isAlphaPremultiplied) {
                                n22 *= array2[3];
                            }
                        }
                        array2[0] = (float)n2 * n22;
                        array2[1] = (float)n3 * n22;
                        array2[2] = (float)n4 * n22;
                    }
                    else if (this.is_LinearGray_stdScale) {
                        array2[0] = (0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF)) / 65535.0f;
                        if (this.supportsAlpha) {
                            array2[1] = (float)(n >> 24 & 0xFF) * 0.003921569f;
                            if (this.isAlphaPremultiplied) {
                                int n21 = 0;
                                array2[n21] *= array2[1];
                            }
                        }
                    }
                    else if (this.is_ICCGray_stdScale) {
                        array2[0] = (float)(this.fromLinearGray16ToOtherGray16LUT[(int)(0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF) + 0.5f)] & 0xFFFF) / 65535.0f;
                        if (this.supportsAlpha) {
                            array2[1] = (float)(n >> 24 & 0xFF) * 0.003921569f;
                            if (this.isAlphaPremultiplied) {
                                int n20 = 0;
                                array2[n20] *= array2[1];
                            }
                        }
                    }
                    else {
                        float[] array3 = new float[3];
                        float n16 = 0.003921569f;
                        array3[0] = (float)n2 * n16;
                        array3[1] = (float)n3 * n16;
                        array3[2] = (float)n4 * n16;
                        float[] fromRGB2 = this.colorSpace.fromRGB(array3);
                        if (this.supportsAlpha) {
                            int n17 = n >> 24 & 0xFF;
                            array2[this.numColorComponents] = (float)n17 * n16;
                            if (this.isAlphaPremultiplied) {
                                float n18 = n16 * (float)n17;
                                for (int k = 0; k < this.numColorComponents; ++k) {
                                    int n19 = k;
                                    fromRGB2[n19] *= n18;
                                }
                            }
                        }
                        for (int l = 0; l < this.numColorComponents; ++l) {
                            array2[l] = fromRGB2[l];
                        }
                    }
                    return array2;
                }
                case 5: {
                    double[] array4;
                    if (o == null) {
                        array4 = new double[this.numComponents];
                    }
                    else {
                        array4 = (double[])(double[])o;
                    }
                    if (this.is_sRGB_stdScale || this.is_LinearRGB_stdScale) {
                        double n31;
                        if (this.is_LinearRGB_stdScale) {
                            n2 = (this.fromsRGB8LUT16[n2] & 0xFFFF);
                            n3 = (this.fromsRGB8LUT16[n3] & 0xFFFF);
                            n4 = (this.fromsRGB8LUT16[n4] & 0xFFFF);
                            n31 = 1.5259021896696422E-5;
                        }
                        else {
                            n31 = 0.00392156862745098;
                        }
                        if (this.supportsAlpha) {
                            array4[3] = (double)(n >> 24 & 0xFF) * 0.00392156862745098;
                            if (this.isAlphaPremultiplied) {
                                n31 *= array4[3];
                            }
                        }
                        array4[0] = (double)n2 * n31;
                        array4[1] = (double)n3 * n31;
                        array4[2] = (double)n4 * n31;
                    }
                    else if (this.is_LinearGray_stdScale) {
                        array4[0] = (0.2125 * (double)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154 * (double)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721 * (double)(this.fromsRGB8LUT16[n4] & 0xFFFF)) / 65535.0;
                        if (this.supportsAlpha) {
                            array4[1] = (double)(n >> 24 & 0xFF) * 0.00392156862745098;
                            if (this.isAlphaPremultiplied) {
                                int n30 = 0;
                                array4[n30] *= array4[1];
                            }
                        }
                    }
                    else if (this.is_ICCGray_stdScale) {
                        array4[0] = (double)(this.fromLinearGray16ToOtherGray16LUT[(int)(0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF) + 0.5f)] & 0xFFFF) / 65535.0;
                        if (this.supportsAlpha) {
                            array4[1] = (double)(n >> 24 & 0xFF) * 0.00392156862745098;
                            if (this.isAlphaPremultiplied) {
                                int n29 = 0;
                                array4[n29] *= array4[1];
                            }
                        }
                    }
                    else {
                        float n23 = 0.003921569f;
                        float[] fromRGB3 = this.colorSpace.fromRGB(new float[] { (float)n2 * n23, (float)n3 * n23, (float)n4 * n23 });
                        if (this.supportsAlpha) {
                            int n24 = n >> 24 & 0xFF;
                            array4[this.numColorComponents] = (double)n24 * 0.00392156862745098;
                            if (this.isAlphaPremultiplied) {
                                float n25 = n23 * (float)n24;
                                for (int n26 = 0; n26 < this.numColorComponents; ++n26) {
                                    int n27 = n26;
                                    fromRGB3[n27] *= n25;
                                }
                            }
                        }
                        for (int n28 = 0; n28 < this.numColorComponents; ++n28) {
                            array4[n28] = (double)fromRGB3[n28];
                        }
                    }
                    return array4;
                }
                default: {
                    break;
                }
            }
        }
        int[] array5;
        if (this.transferType == 3 && o != null) {
            array5 = (int[])(int[])o;
        }
        else {
            array5 = new int[this.numComponents];
        }
        if (this.is_sRGB_stdScale || this.is_LinearRGB_stdScale) {
            int n43;
            float n44;
            if (this.is_LinearRGB_stdScale) {
                if (this.transferType == 0) {
                    n2 = (this.fromsRGB8LUT8[n2] & 0xFF);
                    n3 = (this.fromsRGB8LUT8[n3] & 0xFF);
                    n4 = (this.fromsRGB8LUT8[n4] & 0xFF);
                    n43 = 8;
                    n44 = 0.003921569f;
                }
                else {
                    n2 = (this.fromsRGB8LUT16[n2] & 0xFFFF);
                    n3 = (this.fromsRGB8LUT16[n3] & 0xFFFF);
                    n4 = (this.fromsRGB8LUT16[n4] & 0xFFFF);
                    n43 = 16;
                    n44 = 1.5259022E-5f;
                }
            }
            else {
                n43 = 8;
                n44 = 0.003921569f;
            }
            if (this.supportsAlpha) {
                int n45 = n >> 24 & 0xFF;
                if (this.nBits[3] == 8) {
                    array5[3] = n45;
                }
                else {
                    array5[3] = (int)((float)n45 * 0.003921569f * (float)((1 << this.nBits[3]) - 1) + 0.5f);
                }
                if (this.isAlphaPremultiplied) {
                    n44 *= (float)n45 * 0.003921569f;
                    n43 = -1;
                }
            }
            if (this.nBits[0] == n43) {
                array5[0] = n2;
            }
            else {
                array5[0] = (int)((float)n2 * n44 * (float)((1 << this.nBits[0]) - 1) + 0.5f);
            }
            if (this.nBits[1] == n43) {
                array5[1] = n3;
            }
            else {
                array5[1] = (int)((float)n3 * n44 * (float)((1 << this.nBits[1]) - 1) + 0.5f);
            }
            if (this.nBits[2] == n43) {
                array5[2] = n4;
            }
            else {
                array5[2] = (int)((float)n4 * n44 * (float)((1 << this.nBits[2]) - 1) + 0.5f);
            }
        }
        else if (this.is_LinearGray_stdScale) {
            float n41 = (0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF)) / 65535.0f;
            if (this.supportsAlpha) {
                int n42 = n >> 24 & 0xFF;
                if (this.nBits[1] == 8) {
                    array5[1] = n42;
                }
                else {
                    array5[1] = (int)((float)n42 * 0.003921569f * (float)((1 << this.nBits[1]) - 1) + 0.5f);
                }
                if (this.isAlphaPremultiplied) {
                    n41 *= (float)n42 * 0.003921569f;
                }
            }
            array5[0] = (int)(n41 * (float)((1 << this.nBits[0]) - 1) + 0.5f);
        }
        else if (this.is_ICCGray_stdScale) {
            float n39 = (float)(this.fromLinearGray16ToOtherGray16LUT[(int)(0.2125f * (float)(this.fromsRGB8LUT16[n2] & 0xFFFF) + 0.7154f * (float)(this.fromsRGB8LUT16[n3] & 0xFFFF) + 0.0721f * (float)(this.fromsRGB8LUT16[n4] & 0xFFFF) + 0.5f)] & 0xFFFF) / 65535.0f;
            if (this.supportsAlpha) {
                int n40 = n >> 24 & 0xFF;
                if (this.nBits[1] == 8) {
                    array5[1] = n40;
                }
                else {
                    array5[1] = (int)((float)n40 * 0.003921569f * (float)((1 << this.nBits[1]) - 1) + 0.5f);
                }
                if (this.isAlphaPremultiplied) {
                    n39 *= (float)n40 * 0.003921569f;
                }
            }
            array5[0] = (int)(n39 * (float)((1 << this.nBits[0]) - 1) + 0.5f);
        }
        else {
            float[] array6 = new float[3];
            float n32 = 0.003921569f;
            array6[0] = (float)n2 * n32;
            array6[1] = (float)n3 * n32;
            array6[2] = (float)n4 * n32;
            float[] fromRGB4 = this.colorSpace.fromRGB(array6);
            if (this.nonStdScale) {
                for (int n33 = 0; n33 < this.numColorComponents; ++n33) {
                    fromRGB4[n33] = (fromRGB4[n33] - this.compOffset[n33]) * this.compScale[n33];
                    if (fromRGB4[n33] < 0.0f) {
                        fromRGB4[n33] = 0.0f;
                    }
                    if (fromRGB4[n33] > 1.0f) {
                        fromRGB4[n33] = 1.0f;
                    }
                }
            }
            if (this.supportsAlpha) {
                int n34 = n >> 24 & 0xFF;
                if (this.nBits[this.numColorComponents] == 8) {
                    array5[this.numColorComponents] = n34;
                }
                else {
                    array5[this.numColorComponents] = (int)((float)n34 * n32 * (float)((1 << this.nBits[this.numColorComponents]) - 1) + 0.5f);
                }
                if (this.isAlphaPremultiplied) {
                    float n35 = n32 * (float)n34;
                    for (int n36 = 0; n36 < this.numColorComponents; ++n36) {
                        int n37 = n36;
                        fromRGB4[n37] *= n35;
                    }
                }
            }
            for (int n38 = 0; n38 < this.numColorComponents; ++n38) {
                array5[n38] = (int)(fromRGB4[n38] * (float)((1 << this.nBits[n38]) - 1) + 0.5f);
            }
        }
        switch (this.transferType) {
            case 0: {
                byte[] array7;
                if (o == null) {
                    array7 = new byte[this.numComponents];
                }
                else {
                    array7 = (byte[])(byte[])o;
                }
                for (int n46 = 0; n46 < this.numComponents; ++n46) {
                    array7[n46] = (byte)(0xFF & array5[n46]);
                }
                return array7;
            }
            case 1: {
                short[] array8;
                if (o == null) {
                    array8 = new short[this.numComponents];
                }
                else {
                    array8 = (short[])(short[])o;
                }
                for (int n47 = 0; n47 < this.numComponents; ++n47) {
                    array8[n47] = (short)(array5[n47] & 0xFFFF);
                }
                return array8;
            }
            case 3: {
                if (this.maxBits > 23) {
                    for (int n48 = 0; n48 < this.numComponents; ++n48) {
                        if (array5[n48] > (1 << this.nBits[n48]) - 1) {
                            array5[n48] = (1 << this.nBits[n48]) - 1;
                        }
                    }
                    return array5;
                }
                return array5;
            }
            default: {
                throw new IllegalArgumentException("This method has not been implemented for transferType " + this.transferType);
            }
        }
    }
    
    @Override
    public int[] getComponents(int n, int[] array, int n2) {
        if (this.numComponents > 1) {
            throw new IllegalArgumentException("More than one component per pixel");
        }
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.noUnnorm) {
            throw new IllegalArgumentException("This ColorModel does not support the unnormalized form");
        }
        if (array == null) {
            array = new int[n2 + 1];
        }
        array[n2 + 0] = (n & (1 << this.nBits[0]) - 1);
        return array;
    }
    
    @Override
    public int[] getComponents(Object o, int[] array, int n) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.noUnnorm) {
            throw new IllegalArgumentException("This ColorModel does not support the unnormalized form");
        }
        int[] intArray;
        if ((o instanceof int[])) {
            intArray = (int[])(int[])o;
        }
        else {
            intArray = DataBuffer.toIntArray(o);
            if (intArray == null) {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
        if (intArray.length < this.numComponents) {
            throw new IllegalArgumentException("Length of pixel array < number of components in model");
        }
        if (array == null) {
            array = new int[n + this.numComponents];
        }
        else if (array.length - n < this.numComponents) {
            throw new IllegalArgumentException("Length of components array < number of components in model");
        }
        System.arraycopy(intArray, 0, array, n, this.numComponents);
        return array;
    }
    
    @Override
    public int[] getUnnormalizedComponents(float[] array, int n, int[] array2, int n2) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.noUnnorm) {
            throw new IllegalArgumentException("This ColorModel does not support the unnormalized form");
        }
        return super.getUnnormalizedComponents(array, n, array2, n2);
    }
    
    @Override
    public float[] getNormalizedComponents(int[] array, int n, float[] array2, int n2) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.noUnnorm) {
            throw new IllegalArgumentException("This ColorModel does not support the unnormalized form");
        }
        return super.getNormalizedComponents(array, n, array2, n2);
    }
    
    @Override
    public int getDataElement(int[] array, int n) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.numComponents == 1) {
            if (this.noUnnorm) {
                throw new IllegalArgumentException("This ColorModel does not support the unnormalized form");
            }
            return array[n + 0];
        }
        else {
            throw new IllegalArgumentException("This model returns " + this.numComponents + " elements in the pixel array.");
        }
    }
    
    @Override
    public Object getDataElements(int[] array, int n, Object o) {
        if (this.needScaleInit) {
            this.initScale();
        }
        if (this.noUnnorm) {
            throw new IllegalArgumentException("This ColorModel does not support the unnormalized form");
        }
        if (array.length - n < this.numComponents) {
            throw new IllegalArgumentException("Component array too small (should be " + this.numComponents);
        }
        switch (this.transferType) {
            case 3: {
                int[] array2;
                if (o == null) {
                    array2 = new int[this.numComponents];
                }
                else {
                    array2 = (int[])(int[])o;
                }
                System.arraycopy(array, n, array2, 0, this.numComponents);
                return array2;
            }
            case 0: {
                byte[] array3;
                if (o == null) {
                    array3 = new byte[this.numComponents];
                }
                else {
                    array3 = (byte[])(byte[])o;
                }
                for (int i = 0; i < this.numComponents; ++i) {
                    array3[i] = (byte)(array[n + i] & 0xFF);
                }
                return array3;
            }
            case 1: {
                short[] array4;
                if (o == null) {
                    array4 = new short[this.numComponents];
                }
                else {
                    array4 = (short[])(short[])o;
                }
                for (int j = 0; j < this.numComponents; ++j) {
                    array4[j] = (short)(array[n + j] & 0xFFFF);
                }
                return array4;
            }
            default: {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
    }
    
    @Override
    public int getDataElement(float[] array, int n) {
        if (this.numComponents > 1) {
            throw new IllegalArgumentException("More than one component per pixel");
        }
        if (this.signed) {
            throw new IllegalArgumentException("Component value is signed");
        }
        if (this.needScaleInit) {
            this.initScale();
        }
        Object dataElements = this.getDataElements(array, n, null);
        switch (this.transferType) {
            case 0: {
                return ((byte[])(byte[])dataElements)[0] & 0xFF;
            }
            case 1: {
                return ((short[])(short[])dataElements)[0] & 0xFFFF;
            }
            case 3: {
                return ((int[])(int[])dataElements)[0];
            }
            default: {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
    }
    
    @Override
    public Object getDataElements(float[] array, int n, Object o) {
        int n2 = this.supportsAlpha && this.isAlphaPremultiplied;
        if (this.needScaleInit) {
            this.initScale();
        }
        float[] array2;
        if (this.nonStdScale) {
            array2 = new float[this.numComponents];
            int i;
            for (i = 0, ; i < this.numColorComponents; ++i, ++n) {
                array2[i] = (array[n] - this.compOffset[i]) * this.compScale[i];
                if (array2[i] < 0.0f) {
                    array2[i] = 0.0f;
                }
                if (array2[i] > 1.0f) {
                    array2[i] = 1.0f;
                }
            }
            if (this.supportsAlpha) {
                array2[this.numColorComponents] = array[this.numColorComponents + n];
            }
            n = 0;
        }
        else {
            array2 = array;
        }
        switch (this.transferType) {
            case 0: {
                byte[] array3;
                if (o == null) {
                    array3 = new byte[this.numComponents];
                }
                else {
                    array3 = (byte[])(byte[])o;
                }
                if (!(n2 == 0)) {
                    float n3 = array2[this.numColorComponents + n];
                    int k;
                    for (k = 0, ; k < this.numColorComponents; ++k, ++n) {
                        array3[k] = (byte)(int)(array2[n] * n3 * (float)((1 << this.nBits[k]) - 1) + 0.5f);
                    }
                    array3[this.numColorComponents] = (byte)(int)(n3 * (float)((1 << this.nBits[this.numColorComponents]) - 1) + 0.5f);
                    return array3;
                }
                int j;
                for (j = 0, ; j < this.numComponents; ++j, ++n) {
                    array3[j] = (byte)(int)(array2[n] * (float)((1 << this.nBits[j]) - 1) + 0.5f);
                }
                return array3;
            }
            case 1: {
                short[] array4;
                if (o == null) {
                    array4 = new short[this.numComponents];
                }
                else {
                    array4 = (short[])(short[])o;
                }
                if (!(n2 == 0)) {
                    float n4 = array2[this.numColorComponents + n];
                    int n5;
                    for (n5 = 0, ; n5 < this.numColorComponents; ++n5, ++n) {
                        array4[n5] = (short)(int)(array2[n] * n4 * (float)((1 << this.nBits[n5]) - 1) + 0.5f);
                    }
                    array4[this.numColorComponents] = (short)(int)(n4 * (float)((1 << this.nBits[this.numColorComponents]) - 1) + 0.5f);
                    return array4;
                }
                int l;
                for (l = 0, ; l < this.numComponents; ++l, ++n) {
                    array4[l] = (short)(int)(array2[n] * (float)((1 << this.nBits[l]) - 1) + 0.5f);
                }
                return array4;
            }
            case 3: {
                int[] array5;
                if (o == null) {
                    array5 = new int[this.numComponents];
                }
                else {
                    array5 = (int[])(int[])o;
                }
                if (!(n2 == 0)) {
                    float n7 = array2[this.numColorComponents + n];
                    int n8;
                    for (n8 = 0, ; n8 < this.numColorComponents; ++n8, ++n) {
                        array5[n8] = (int)(array2[n] * n7 * (float)((1 << this.nBits[n8]) - 1) + 0.5f);
                    }
                    array5[this.numColorComponents] = (int)(n7 * (float)((1 << this.nBits[this.numColorComponents]) - 1) + 0.5f);
                    return array5;
                }
                int n6;
                for (n6 = 0, ; n6 < this.numComponents; ++n6, ++n) {
                    array5[n6] = (int)(array2[n] * (float)((1 << this.nBits[n6]) - 1) + 0.5f);
                }
                return array5;
            }
            case 2: {
                short[] array6;
                if (o == null) {
                    array6 = new short[this.numComponents];
                }
                else {
                    array6 = (short[])(short[])o;
                }
                if (!(n2 == 0)) {
                    float n10 = array2[this.numColorComponents + n];
                    int n11;
                    for (n11 = 0, ; n11 < this.numColorComponents; ++n11, ++n) {
                        array6[n11] = (short)(int)(array2[n] * n10 * 32767.0f + 0.5f);
                    }
                    array6[this.numColorComponents] = (short)(int)(n10 * 32767.0f + 0.5f);
                    return array6;
                }
                int n9;
                for (n9 = 0, ; n9 < this.numComponents; ++n9, ++n) {
                    array6[n9] = (short)(int)(array2[n] * 32767.0f + 0.5f);
                }
                return array6;
            }
            case 4: {
                float[] array7;
                if (o == null) {
                    array7 = new float[this.numComponents];
                }
                else {
                    array7 = (float[])(float[])o;
                }
                if (!(n2 == 0)) {
                    float n13 = array[this.numColorComponents + n];
                    int n14;
                    for (n14 = 0, ; n14 < this.numColorComponents; ++n14, ++n) {
                        array7[n14] = array[n] * n13;
                    }
                    array7[this.numColorComponents] = n13;
                    return array7;
                }
                int n12;
                for (n12 = 0, ; n12 < this.numComponents; ++n12, ++n) {
                    array7[n12] = array[n];
                }
                return array7;
            }
            case 5: {
                double[] array8;
                if (o == null) {
                    array8 = new double[this.numComponents];
                }
                else {
                    array8 = (double[])(double[])o;
                }
                if (!(n2 == 0)) {
                    double n16 = (double)array[this.numColorComponents + n];
                    int n17;
                    for (n17 = 0, ; n17 < this.numColorComponents; ++n17, ++n) {
                        array8[n17] = (double)array[n] * n16;
                    }
                    array8[this.numColorComponents] = n16;
                    return array8;
                }
                int n15;
                for (n15 = 0, ; n15 < this.numComponents; ++n15, ++n) {
                    array8[n15] = (double)array[n];
                }
                return array8;
            }
            default: {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
    }
    
    @Override
    public float[] getNormalizedComponents(Object o, float[] array, int i) {
        if (array == null) {
            array = new float[this.numComponents + i];
        }
        switch (this.transferType) {
            case 0: {
                byte[] array2 = (byte[])(byte[])o;
                int j;
                for (j = 0, ; j < this.numComponents; ++j, ++i) {
                    array[i] = (float)(array2[j] & 0xFF) / (float)((1 << this.nBits[j]) - 1);
                }
                break;
            }
            case 1: {
                short[] array3 = (short[])(short[])o;
                int k;
                for (k = 0, ; k < this.numComponents; ++k, ++i) {
                    array[i] = (float)(array3[k] & 0xFFFF) / (float)((1 << this.nBits[k]) - 1);
                }
                break;
            }
            case 3: {
                int[] array4 = (int[])(int[])o;
                int l;
                for (l = 0, ; l < this.numComponents; ++l, ++i) {
                    array[i] = (float)array4[l] / (float)((1 << this.nBits[l]) - 1);
                }
                break;
            }
            case 2: {
                short[] array5 = (short[])(short[])o;
                int n;
                for (n = 0, ; n < this.numComponents; ++n, ++i) {
                    array[i] = (float)array5[n] / 32767.0f;
                }
                break;
            }
            case 4: {
                float[] array6 = (float[])(float[])o;
                int n2;
                for (n2 = 0, ; n2 < this.numComponents; ++n2, ++i) {
                    array[i] = array6[n2];
                }
                break;
            }
            case 5: {
                double[] array7 = (double[])(double[])o;
                int n3;
                for (n3 = 0, ; n3 < this.numComponents; ++n3, ++i) {
                    array[i] = (float)array7[n3];
                }
                break;
            }
            default: {
                throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
            }
        }
        if (this.supportsAlpha && this.isAlphaPremultiplied) {
            float n4 = array[this.numColorComponents + i];
            if (n4 != 0.0f) {
                float n5 = 1.0f / n4;
                float[] array8;
                int n6;
                for (; i < this.numColorComponents + i; ++i) {
                    array8 = array;
                    n6 = i;
                    array8[n6] *= n5;
                }
            }
        }
        if (this.min != null) {
            for (int n7 = 0; n7 < this.numColorComponents; ++n7) {
                array[n7 + i] = this.min[n7] + this.diffMinMax[n7] * array[n7 + i];
            }
            return array;
        }
        return array;
    }
    
    @Override
    public ColorModel coerceData(WritableRaster writableRaster, boolean b) {
        if (!this.supportsAlpha || this.isAlphaPremultiplied == b) {
            return this;
        }
        int width = writableRaster.getWidth();
        int height = writableRaster.getHeight();
        int n = writableRaster.getNumBands() - 1;
        int minX = writableRaster.getMinX();
        int minY = writableRaster.getMinY();
        if (b) {
            switch (this.transferType) {
                case 0: {
                    byte[] array7 = null;
                    byte[] a = null;
                    float n34 = 1.0f / (float)((1 << this.nBits[n]) - 1);
                    for (int n35 = 0; n35 < height; ++n35, ++minY) {
                        for (int n36 = 0; n36 < width; ++n36, ++minX) {
                            array7 = (byte[])(byte[])writableRaster.getDataElements(minX, minY, array7);
                            float n37 = (float)(array7[n] & 0xFF) * n34;
                            if (n37 != 0.0f) {
                                for (int n38 = 0; n38 < n; ++n38) {
                                    array7[n38] = (byte)(int)((float)(array7[n38] & 0xFF) * n37 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array7);
                            }
                            else {
                                if (a == null) {
                                    a = new byte[this.numComponents];
                                    Arrays.fill(a, (byte)0);
                                }
                                writableRaster.setDataElements(minX, minY, a);
                            }
                        }
                    }
                    break;
                }
                case 1: {
                    short[] array8 = null;
                    short[] a2 = null;
                    float n39 = 1.0f / (float)((1 << this.nBits[n]) - 1);
                    for (int n40 = 0; n40 < height; ++n40, ++minY) {
                        for (int n41 = 0; n41 < width; ++n41, ++minX) {
                            array8 = (short[])(short[])writableRaster.getDataElements(minX, minY, array8);
                            float n42 = (float)(array8[n] & 0xFFFF) * n39;
                            if (n42 != 0.0f) {
                                for (int n43 = 0; n43 < n; ++n43) {
                                    array8[n43] = (short)(int)((float)(array8[n43] & 0xFFFF) * n42 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array8);
                            }
                            else {
                                if (a2 == null) {
                                    a2 = new short[this.numComponents];
                                    Arrays.fill(a2, (short)0);
                                }
                                writableRaster.setDataElements(minX, minY, a2);
                            }
                        }
                    }
                    break;
                }
                case 3: {
                    int[] array9 = null;
                    int[] a3 = null;
                    float n44 = 1.0f / (float)((1 << this.nBits[n]) - 1);
                    for (int n45 = 0; n45 < height; ++n45, ++minY) {
                        for (int n46 = 0; n46 < width; ++n46, ++minX) {
                            array9 = (int[])(int[])writableRaster.getDataElements(minX, minY, array9);
                            float n47 = (float)array9[n] * n44;
                            if (n47 != 0.0f) {
                                for (int n48 = 0; n48 < n; ++n48) {
                                    array9[n48] = (int)((float)array9[n48] * n47 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array9);
                            }
                            else {
                                if (a3 == null) {
                                    a3 = new int[this.numComponents];
                                    Arrays.fill(a3, 0);
                                }
                                writableRaster.setDataElements(minX, minY, a3);
                            }
                        }
                    }
                    break;
                }
                case 2: {
                    short[] array10 = null;
                    short[] a4 = null;
                    float n49 = 3.051851E-5f;
                    for (int n50 = 0; n50 < height; ++n50, ++minY) {
                        for (int n51 = 0; n51 < width; ++n51, ++minX) {
                            array10 = (short[])(short[])writableRaster.getDataElements(minX, minY, array10);
                            float n52 = (float)array10[n] * n49;
                            if (n52 != 0.0f) {
                                for (int n53 = 0; n53 < n; ++n53) {
                                    array10[n53] = (short)(int)((float)array10[n53] * n52 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array10);
                            }
                            else {
                                if (a4 == null) {
                                    a4 = new short[this.numComponents];
                                    Arrays.fill(a4, (short)0);
                                }
                                writableRaster.setDataElements(minX, minY, a4);
                            }
                        }
                    }
                    break;
                }
                case 4: {
                    float[] array11 = null;
                    float[] a5 = null;
                    for (int n54 = 0; n54 < height; ++n54, ++minY) {
                        for (int n55 = 0; n55 < width; ++n55, ++minX) {
                            array11 = (float[])(float[])writableRaster.getDataElements(minX, minY, array11);
                            float n56 = array11[n];
                            if (n56 != 0.0f) {
                                for (int n57 = 0; n57 < n; ++n57) {
                                    int n58 = n57;
                                    array11[n58] *= n56;
                                }
                                writableRaster.setDataElements(minX, minY, array11);
                            }
                            else {
                                if (a5 == null) {
                                    a5 = new float[this.numComponents];
                                    Arrays.fill(a5, 0.0f);
                                }
                                writableRaster.setDataElements(minX, minY, a5);
                            }
                        }
                    }
                    break;
                }
                case 5: {
                    double[] array12 = null;
                    double[] a6 = null;
                    for (int n59 = 0; n59 < height; ++n59, ++minY) {
                        for (int n60 = 0; n60 < width; ++n60, ++minX) {
                            array12 = (double[])(double[])writableRaster.getDataElements(minX, minY, array12);
                            double n61 = array12[n];
                            if (n61 != 0.0) {
                                for (int n62 = 0; n62 < n; ++n62) {
                                    int n63 = n62;
                                    array12[n63] *= n61;
                                }
                                writableRaster.setDataElements(minX, minY, array12);
                            }
                            else {
                                if (a6 == null) {
                                    a6 = new double[this.numComponents];
                                    Arrays.fill(a6, 0.0);
                                }
                                writableRaster.setDataElements(minX, minY, a6);
                            }
                        }
                    }
                    break;
                }
                default: {
                    throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
                }
            }
        }
        else {
            switch (this.transferType) {
                case 0: {
                    byte[] array = null;
                    float n2 = 1.0f / (float)((1 << this.nBits[n]) - 1);
                    for (int i = 0; i < height; ++i, ++minY) {
                        for (int j = 0; j < width; ++j, ++minX) {
                            array = (byte[])(byte[])writableRaster.getDataElements(minX, minY, array);
                            float n3 = (float)(array[n] & 0xFF) * n2;
                            if (n3 != 0.0f) {
                                float n4 = 1.0f / n3;
                                for (int k = 0; k < n; ++k) {
                                    array[k] = (byte)(int)((float)(array[k] & 0xFF) * n4 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array);
                            }
                        }
                    }
                    break;
                }
                case 1: {
                    short[] array2 = null;
                    float n5 = 1.0f / (float)((1 << this.nBits[n]) - 1);
                    for (int l = 0; l < height; ++l, ++minY) {
                        for (int n6 = 0; n6 < width; ++n6, ++minX) {
                            array2 = (short[])(short[])writableRaster.getDataElements(minX, minY, array2);
                            float n7 = (float)(array2[n] & 0xFFFF) * n5;
                            if (n7 != 0.0f) {
                                float n8 = 1.0f / n7;
                                for (int n9 = 0; n9 < n; ++n9) {
                                    array2[n9] = (short)(int)((float)(array2[n9] & 0xFFFF) * n8 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array2);
                            }
                        }
                    }
                    break;
                }
                case 3: {
                    int[] array3 = null;
                    float n10 = 1.0f / (float)((1 << this.nBits[n]) - 1);
                    for (int n11 = 0; n11 < height; ++n11, ++minY) {
                        for (int n12 = 0; n12 < width; ++n12, ++minX) {
                            array3 = (int[])(int[])writableRaster.getDataElements(minX, minY, array3);
                            float n13 = (float)array3[n] * n10;
                            if (n13 != 0.0f) {
                                float n14 = 1.0f / n13;
                                for (int n15 = 0; n15 < n; ++n15) {
                                    array3[n15] = (int)((float)array3[n15] * n14 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array3);
                            }
                        }
                    }
                    break;
                }
                case 2: {
                    short[] array4 = null;
                    float n16 = 3.051851E-5f;
                    for (int n17 = 0; n17 < height; ++n17, ++minY) {
                        for (int n18 = 0; n18 < width; ++n18, ++minX) {
                            array4 = (short[])(short[])writableRaster.getDataElements(minX, minY, array4);
                            float n19 = (float)array4[n] * n16;
                            if (n19 != 0.0f) {
                                float n20 = 1.0f / n19;
                                for (int n21 = 0; n21 < n; ++n21) {
                                    array4[n21] = (short)(int)((float)array4[n21] * n20 + 0.5f);
                                }
                                writableRaster.setDataElements(minX, minY, array4);
                            }
                        }
                    }
                    break;
                }
                case 4: {
                    float[] array5 = null;
                    for (int n22 = 0; n22 < height; ++n22, ++minY) {
                        for (int n23 = 0; n23 < width; ++n23, ++minX) {
                            array5 = (float[])(float[])writableRaster.getDataElements(minX, minY, array5);
                            float n24 = array5[n];
                            if (n24 != 0.0f) {
                                float n25 = 1.0f / n24;
                                for (int n26 = 0; n26 < n; ++n26) {
                                    int n27 = n26;
                                    array5[n27] *= n25;
                                }
                                writableRaster.setDataElements(minX, minY, array5);
                            }
                        }
                    }
                    break;
                }
                case 5: {
                    double[] array6 = null;
                    for (int n28 = 0; n28 < height; ++n28, ++minY) {
                        for (int n29 = 0; n29 < width; ++n29, ++minX) {
                            array6 = (double[])(double[])writableRaster.getDataElements(minX, minY, array6);
                            double n30 = array6[n];
                            if (n30 != 0.0) {
                                double n31 = 1.0 / n30;
                                for (int n32 = 0; n32 < n; ++n32) {
                                    int n33 = n32;
                                    array6[n33] *= n31;
                                }
                                writableRaster.setDataElements(minX, minY, array6);
                            }
                        }
                    }
                    break;
                }
                default: {
                    throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
                }
            }
        }
        if (!this.signed) {
            return new ComponentColorModel(this.colorSpace, this.nBits, this.supportsAlpha, b, this.transparency, this.transferType);
        }
        return new ComponentColorModel(this.colorSpace, this.supportsAlpha, b, this.transparency, this.transferType);
    }
    
    @Override
    public boolean isCompatibleRaster(Raster raster) {
        SampleModel sampleModel = raster.getSampleModel();
        if ((sampleModel instanceof ComponentSampleModel)) {
            if (sampleModel.getNumBands() != this.getNumComponents()) {
                return false;
            }
            int i = 0;
            while (i < this.nBits.length) {
                if (sampleModel.getSampleSize(i) < this.nBits[i]) {
                    return false;
                }
                ++i;
            }
            return raster.getTransferType() == this.transferType;
        }
        else {
            return false;
        }
    }
    
    @Override
    public WritableRaster createCompatibleWritableRaster(int n, int n2) {
        int n3 = n * n2 * this.numComponents;
        WritableRaster writableRaster;
        switch (this.transferType) {
            case 0:
            case 1: {
                writableRaster = Raster.createInterleavedRaster(this.transferType, n, n2, this.numComponents, null);
                break;
            }
            default: {
                SampleModel compatibleSampleModel = this.createCompatibleSampleModel(n, n2);
                writableRaster = Raster.createWritableRaster(compatibleSampleModel, compatibleSampleModel.createDataBuffer(), null);
                break;
            }
        }
        return writableRaster;
    }
    
    @Override
    public SampleModel createCompatibleSampleModel(int n, int n2) {
        int[] array = new int[this.numComponents];
        for (int i = 0; i < this.numComponents; ++i) {
            array[i] = i;
        }
        switch (this.transferType) {
            case 0:
            case 1: {
                return new PixelInterleavedSampleModel(this.transferType, n, n2, this.numComponents, n * this.numComponents, array);
            }
            default: {
                return new ComponentSampleModel(this.transferType, n, n2, this.numComponents, n * this.numComponents, array);
            }
        }
    }
    
    @Override
    public boolean isCompatibleSampleModel(SampleModel sampleModel) {
        return sampleModel instanceof ComponentSampleModel && this.numComponents == sampleModel.getNumBands() && sampleModel.getTransferType() == this.transferType;
    }
    
    @Override
    public WritableRaster getAlphaRaster(WritableRaster writableRaster) {
        if (!this.hasAlpha()) {
            return null;
        }
        int minX = writableRaster.getMinX();
        int minY = writableRaster.getMinY();
        return writableRaster.createWritableChild(minX, minY, writableRaster.getWidth(), writableRaster.getHeight(), minX, minY, new int[] { writableRaster.getNumBands() - 1 });
    }
    
    @Override
    public boolean equals(Object o) {
        return super.equals(o) && o.getClass() == this.getClass();
    }
}
